summaryrefslogtreecommitdiffstats
path: root/konq-plugins/domtreeviewer/domtreewindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konq-plugins/domtreeviewer/domtreewindow.cpp')
-rw-r--r--konq-plugins/domtreeviewer/domtreewindow.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/konq-plugins/domtreeviewer/domtreewindow.cpp b/konq-plugins/domtreeviewer/domtreewindow.cpp
index 03e3581..4eb5dce 100644
--- a/konq-plugins/domtreeviewer/domtreewindow.cpp
+++ b/konq-plugins/domtreeviewer/domtreewindow.cpp
@@ -56,7 +56,7 @@
using domtreeviewer::ManipulationCommand;
DOMTreeWindow::DOMTreeWindow(PluginDomtreeviewer *plugin)
- : KMainWindow( 0, "DOMTreeWindow" ),
+ : TDEMainWindow( 0, "DOMTreeWindow" ),
m_plugin(plugin), m_view(new DOMTreeView(this, "DOMTreeView", false))
{
part_manager = 0;
@@ -67,7 +67,7 @@ DOMTreeWindow::DOMTreeWindow(PluginDomtreeviewer *plugin)
// accept dnd
setAcceptDrops(true);
// tell the KMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// message window dialog
@@ -132,22 +132,22 @@ void DOMTreeWindow::setupActions()
KStdAction::redisplay(TQT_TQOBJECT(m_view), TQT_SLOT(refresh()), actionCollection());
// toggle manipulation dialog
- KAction *showMsgDlg = new KAction(i18n("Show Message Log"),
+ TDEAction *showMsgDlg = new TDEAction(i18n("Show Message Log"),
CTRL+Key_E, actionCollection(), "show_msg_dlg");
connect(showMsgDlg, TQT_SIGNAL(activated()), TQT_SLOT(showMessageLog()));
-// KAction *custom = new KAction(i18n("Cus&tom Menuitem"), 0,
+// TDEAction *custom = new TDEAction(i18n("Cus&tom Menuitem"), 0,
// this, TQT_SLOT(optionsPreferences()),
// actionCollection(), "custom_action");
// actions for the dom tree list view toolbar
KStdAction::up(TQT_TQOBJECT(view()), TQT_SLOT(moveToParent()), actionCollection(), "tree_up");
- KAction *tree_inc_level = new KAction(i18n("Expand"),
+ TDEAction *tree_inc_level = new TDEAction(i18n("Expand"),
"1rightarrow", CTRL+Key_Greater, TQT_TQOBJECT(view()),
TQT_SLOT(increaseExpansionDepth()), actionCollection(),
"tree_inc_level");
tree_inc_level->setToolTip(i18n("Increase expansion level"));
- KAction *tree_dec_level = new KAction(i18n("Collapse"),
+ TDEAction *tree_dec_level = new TDEAction(i18n("Collapse"),
"1leftarrow", CTRL+Key_Less, TQT_TQOBJECT(view()),
TQT_SLOT(decreaseExpansionDepth()), actionCollection(),
"tree_dec_level");
@@ -155,20 +155,20 @@ void DOMTreeWindow::setupActions()
// actions for the dom tree list view context menu
- del_tree = new KAction(i18n("&Delete"), "editdelete",
+ del_tree = new TDEAction(i18n("&Delete"), "editdelete",
Key_Delete, TQT_TQOBJECT(view()), TQT_SLOT(deleteNodes()),
actionCollection(), "tree_delete");
del_tree->setToolTip(i18n("Delete nodes"));
- /*KAction *new_elem = */new KAction(i18n("New &Element ..."),
- "bookmark", KShortcut(), TQT_TQOBJECT(view()),
+ /*TDEAction *new_elem = */new TDEAction(i18n("New &Element ..."),
+ "bookmark", TDEShortcut(), TQT_TQOBJECT(view()),
TQT_SLOT(slotAddElementDlg()), actionCollection(),
"tree_add_element");
- /*KAction *new_text = */new KAction(i18n("New &Text Node ..."),
- "text", KShortcut(), TQT_TQOBJECT(view()), TQT_SLOT(slotAddTextDlg()),
+ /*TDEAction *new_text = */new TDEAction(i18n("New &Text Node ..."),
+ "text", TDEShortcut(), TQT_TQOBJECT(view()), TQT_SLOT(slotAddTextDlg()),
actionCollection(), "tree_add_text");
// actions for the info panel attribute list context menu
- del_attr = new KAction(i18n("&Delete"), "editdelete",
+ del_attr = new TDEAction(i18n("&Delete"), "editdelete",
Key_Delete, TQT_TQOBJECT(view()), TQT_SLOT(deleteAttributes()),
actionCollection(), "attr_delete");
del_attr->setToolTip(i18n("Delete attributes"));
@@ -67,7 +67,7 @@ DOMTreeWindow::DOMTreeWindow(PluginDomtreeviewer *plugin)
// accept dnd
setAcceptDrops(true);
- // tell the KMainWindow that this is indeed the main widget
+ // tell the TDEMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// message window dialog